@@ -167,7 +167,9 @@ class Query(object):
 
   def parse(self, query):
     if isinstance(query, dict):
-      self.params = {k:urllib.unquote_plus(v) for k, v in query.iteritems()}
+      # py2.7+: {k:urllib.unquote_plus(v) for k, v in query.iteritems()}
+      tmp = dict((k,urllib.unquote_plus(v)) for (k,v) in query.iteritems())
+      self.params = tmp
     else:
       self.params = parse_qs(query)
 
@@ -191,7 +193,8 @@ class Query(object):
     return self
 
   def __str__(self):
-    params = {str(key):str(val) for key, val in self.params.iteritems()}
+    # py2.7+: {str(key):str(val) for key, val in self.params.iteritems()}
+    params = dict((str(key),str(val)) for (key,val) in self.params.iteritems())
     return urllib.urlencode(params)
 
   def __repr__(self):
@@ -665,7 +668,8 @@ def parse_qs(query):
   Parse a query string to a dictionary of parameter key:value pairs, removing
   any duplicate url parameters. I.e. 'a=1&a=2' would become {'a':'1'}.
   """
-  return {key:val[0] for key, val in urlparse.parse_qs(query).iteritems()}
+  # py2.7+: {key:val[0] for key, val in urlparse.parse_qs(query).iteritems()}
+  return dict((k,v[0]) for (k,v) in urlparse.parse_qs(query).iteritems())
 
 def urlsplit(url):
   """
